==> residualvm-0.1.0-sources.tar.bz2: residualvm-0.1.0/engines/grim/sound.h <==
/* ResidualVM - A 3D game interpreter
 *
 * ResidualVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef GRIM_SOUND_H
#define GRIM_SOUND_H

namespace Grim {

class EMISound;
	
class SoundPlayer {
	EMISound *_emiSound;
public:
	SoundPlayer();
	~SoundPlayer();
	bool startVoice(const char *soundName, int volume = 127, int pan = 64);
	bool getSoundStatus(const char *soundName);
	void stopSound(const char *soundName);
	int32 getPosIn60HzTicks(const char *soundName);	
	
	void setVolume(const char *soundName, int volume);
	void setPan(const char *soundName, int pan);
	
	void setMusicState(int stateId);
	uint32 getMsPos(int stateId);
};

extern SoundPlayer *g_sound;
	
} // end of namespace Grim

#endif

==> residualvm-0.1.1-sources.tar.bz2: residualvm-0.1.1/engines/grim/sound.h <==
/* ResidualVM - A 3D game interpreter
 *
 * ResidualVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef GRIM_SOUND_H
#define GRIM_SOUND_H

namespace Grim {

class EMISound;
	
class SoundPlayer {
	EMISound *_emiSound;
public:
	SoundPlayer();
	~SoundPlayer();
	bool startVoice(const char *soundName, int volume = 127, int pan = 64);
	bool getSoundStatus(const char *soundName);
	void stopSound(const char *soundName);
	int32 getPosIn16msTicks(const char *soundName);
	
	void setVolume(const char *soundName, int volume);
	void setPan(const char *soundName, int pan);
	
	void setMusicState(int stateId);
	uint32 getMsPos(int stateId);
};

extern SoundPlayer *g_sound;
	
} // end of namespace Grim

#endif
